
/*
 * GNU General Public License v3.0
 *
 * Permissions of this strong copyleft license are conditioned on making 
 * available complete source code of licensed works and modifications, 
 * which include larger works using a licensed work, under the same license. 
 * Copyright and license notices must be preserved. Contributors provide 
 * an express grant of patent rights.
 *
 * see all: https://github.com/erikni/logni.js/blob/master/LICENSE
 */


export function cookie() {
  	/**
  	 * Create or update cookie
  	 * 
  	 * @param {string} name,
  	 * @param {string} value,
  	 * @param {number} dayNo,
  	 * @static
  	 */
	this.set = function(name, value, dayNo) {
		let expires;
		if (dayNo) {
			let date = new Date();
			date.setTime(date.getTime()+(dayNo*86400*1000));
			expires = `; expires=${date.toGMTString()}`;
		} else {
			expires = '';
		}
		cookies = `${name}=${value}${expires}; path=/`;
		// this.__debug(`cookieSet ${name}="${value}"${expires}`);
	
		return 0;
	};


  	/**
  	 * Read cookie
  	 * 
  	 * @param {string} name,
  	 * @static
  	 */
	this.get = function(name) {
		const cookieNameEQ = name + "=";
		const cookieDecoded = decodeURIComponent(cookies);
		const ca = cookieDecoded.split(';');
		for(let i=0;i < ca.length;i++) {
			let c = ca[i];
			while (c.charAt(0) === ' ') {
				c = c.substring(1,c.length);
			}
			if (c.indexOf(cookieNameEQ) === 0) {
				const ret = c.substring(cookieNameEQ.length,c.length);
				// this.__debug(`cookieGet ${name}="${ret}"`);
				return ret;
			}
		}
		// this.__debug(`cookieGet ${name} not exist`);
		return;
	};


  	/**
  	 * Remove cookie
  	 * 
  	 * @param {string} name,
  	 * @static
  	 */
	this.del = function(name) {
		// this.__debug(`cookieDel ${name}`);
		this.setCookie(name, '', -1);

		return 0;
	};
};
